-- 神域试炼buff选择
Lua_DivineDomainTrialBuffWindow = class("Lua_DivineDomainTrialBuffWindow", Lua_Window);
function Lua_DivineDomainTrialBuffWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_DivineDomainTrialBuffWindow";
	self.skinName = "DivineDomainTrialBuffWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_DivineDomainTrialBuffWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.sureBtn:setStyle(5);
	self.refleshBtn:setStyle(3);
	self.refleshBtn:setLangValue(764030);
	self.titleNameTxt:setLangValue(764053);
	self.sureBtn:addClickFuntion(self, self.onClickSureBtn);
	self.refleshBtn:addClickFuntion(self, self.onClickRefleshBtn);

	self:addLuaEvent("UPDATE_DIVINEDOMAINTRIAL_BUFF", self, self.updateBuff); -- 刷新buff
	self:addLuaEvent("REQUIRE_DIVINEDOMAINTRIAL_BUFF", self, self.updateBuffData); -- 请求buff
	self:addLuaEvent("UPDATE_DIVINEDOMAINTRIAL_SELECTING_BUFF", self, self.showSelectingBuffData); -- 挑选buff
end

function Lua_DivineDomainTrialBuffWindow:showWin(param) 
	self:superCall("showData", param);

	self.trialId = param;

	local buffData = DataCenter.divineDomainTrialData:getSelectBuffDataByTrialId(self.trialId);
	if buffData == nil then
		self:sendBuffData();
		return;
	end

	self:updateBuffData();
end

function Lua_DivineDomainTrialBuffWindow:updateBuffData()
	local buffId = DataCenter.divineDomainTrialData:getBuffDicByTrialId(self.trialId);
	local bSelectMode = buffId == nil or buffId == 0;
	self:updateBuff(bSelectMode)
end

function Lua_DivineDomainTrialBuffWindow:sendBuffData()
	local type = DataCenter.divineDomainTrialUtil:getBuffTypeByTrialId(self.trialId);
	Lua_ProxyManager.getProxy("Lua_DivineDomainTrialProxy"):sGetSelectBuffsInfo(type) -- 1 普通 2特殊
end

function Lua_DivineDomainTrialBuffWindow:dispose()
	if self.buffItems ~= nil then
		for i = 1, #self.buffItems do
			self.buffItems[i]:dispose();
			self.buffItems[i] = nil;
		end
		self.buffItems = nil;
	end

	self:superCall("dispose");
end

function Lua_DivineDomainTrialBuffWindow:onClickSureBtn()
	if not DataCenter.divineDomainTrialData:checkTrialOpened(self.trialId, true) then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(764012);
		return;
	end
	self.clickTime = getTime();

	local bBuffSelectMode = DataCenter.divineDomainTrialData.bBuffSelectMode;
	if not bBuffSelectMode then
		self:hide();
		return; 
	end

	local buff_id = DataCenter.divineDomainTrialData.curSelectingBuffId; 
	if buff_id == nil or buff_id == 0 then
		OperateAlert.showLangValue(764032);
		return;
	end

	local type = DataCenter.divineDomainTrialUtil:getBuffTypeByTrialId(self.trialId);
	Lua_ProxyManager.getProxy("Lua_DivineDomainTrialProxy"):sGetSelectedBuffInfo(buff_id, type); -- 1 普通 2特殊
	self:hide();
end

function Lua_DivineDomainTrialBuffWindow:onClickRefleshBtn()
	if not DataCenter.divineDomainTrialData:checkTrialOpened(self.trialId, true) then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(764012);
		return;
	end
	self.clickTime = getTime();


	local residueCount = DataCenter.divineDomainTrialData:getBuffRefleshCount(self.trialId) or 0;
	if residueCount <= 0 then
		OperateAlert.showLangValue(764033);
	else
		local costItems = getConfig("domain_trial_const", "buff_pay", "arr_value");
		local hasCount = DataCenter.packData:getItemCountById(costItems[1][1]);
		if hasCount < costItems[1][2] then
			DataCenter.packUtil:openPathWindow(costItems[1][1], false);
			return;
		end

		local tipsData = { 
			des = LanUtil.formateStr(764034, costItems[1][2], spliceIconStrById(costItems[1][1])), 
			btnType = 1, 
			owner = self, 
			sureFun = self.sendRefleshBuff };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_DivineDomainTrialBuffWindow:sendRefleshBuff()
	local type = DataCenter.divineDomainTrialUtil:getBuffTypeByTrialId(self.trialId);
	Lua_ProxyManager.getProxy("Lua_DivineDomainTrialProxy"):sGetReflashBuffInfo(type) -- 1 普通 2特殊
end

function Lua_DivineDomainTrialBuffWindow:updateBuff(bSelectMode)
	DataCenter.divineDomainTrialData:setBuffSelectMode(bSelectMode, self.trialId);
	self:showSelectingBuffData();

	local residueCount = DataCenter.divineDomainTrialData:getBuffRefleshCount(self.trialId) or 0;
	local totalCount = getConfig("domain_trial_const", "buff_refresh", "value");
	local str;
	if residueCount > 0 then
		str = 764035;
	else
		str = 764036;
	end
	self.refleshCountTxt.text = LanUtil.formateStr(str, residueCount, totalCount);
end

function Lua_DivineDomainTrialBuffWindow:showSelectingBuffData()
	local buffData = DataCenter.divineDomainTrialData:getSelectBuffDataByTrialId(self.trialId);
	if buffData == nil then
		return;
	end

	if self.buffItems == nil then
		self.buffItems = {};
	end

	local item;
	local posX;
	local startPosX, distanceX = -233, 234;
	for i = 1, #buffData do
		item = self.buffItems[i];
		if item == nil then
			item = Lua_DivineDomainTrialBuffHorItem.new(self.content);
			self.buffItems[i] = item;
		end
		posX = startPosX + (i - 1) * distanceX;
		item:setData(buffData[i]);
		item:setEnable(true);
		item:setLocation(posX, 0);
	end


	if #self.buffItems > #buffData then
		for i = #buffData + 1, #self.buffItems do
			self.buffItems[i]:setEnable(false);
		end
	end
end









-----------------------------------------------------------------------------------



Lua_DivineDomainTrialBuffHorItem = class("Lua_DivineDomainTrialBuffHorItem", Lua_ListCell);
function Lua_DivineDomainTrialBuffHorItem:ctor(p)
	self:superCall("ctor", p, "DivineDomainTrialBuffHorItem_skin");
end

function Lua_DivineDomainTrialBuffHorItem:buildShowItem()
	self:superCall("buildShowItem");

	self.skillItem = Lua_SkillIconItem.new(self.content);
	self.skillItem:setCanClick(true);
	self.skillItem:setLocation(0, 146);

	self.selectedSp:setEnable(false);
	self.desTxt = UICreate.createLabel(self.content, "", 0, -67, 181, 53, 18);
	self.desTxt.verticalOverflowValue = 1;
	self.desTxt.alignmentValue = 0;
	self.desTxt.colorStr = Lua_ColorDefine.transColorStr("6f645b");

	self.buffBg.clickScale = false;
	self.buffBg:addClickFuntion(self, self.onClickItemBg);
end

function Lua_DivineDomainTrialBuffHorItem:dispose()
	if self.desTxt ~= nil then
		self.desTxt:dispose();
		self.desTxt = nil;
	end
	if self.skillItem ~= nil then
		self.skillItem:dispose();
		self.skillItem = nil;
	end
	self:superCall("dispose");
end

function Lua_DivineDomainTrialBuffHorItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local config = Lua_SkillConfigData.getConfigData(data);
	if config ~= nil then	
		self.buffNameTxt.text = config.name;
		self.desTxt.text = config.des;
		self:showDisplay(config.quality);
		self.skillItem:setData(config);
	end

	self.bBuffSelectMode = DataCenter.divineDomainTrialData.bBuffSelectMode;
	self.bSelectedItem = DataCenter.divineDomainTrialData.curSelectingBuffId == self.data; -- 是否为被选中的item
	if self.bBuffSelectMode then
		self:showSelectingMode(); -- 选择模式
	else
		self:showSelected(); -- 非选择模式
	end
end

function Lua_DivineDomainTrialBuffHorItem:showDisplay(quality)
	local path;
	local colorStr;
	if quality == 4 then
		colorStr = "8843bd";
		path = "/images/divineDomainTrial/xui_sysl_button_10.png";
	elseif quality == 5 then
		colorStr = "d37530";
		path = "/images/divineDomainTrial/xui_sysl_button_12.png";
	-- elseif quality == 3 then
	else
		colorStr = "577bc5";
		path = "/images/divineDomainTrial/xui_sysl_button_11.png";
	end

	self.buffBg:setUrl(path);	
	self.buffBg:setGray(false);
	self.skillItem:setGray(false);
	self.selectedSp:setEnable(false);
	self.selectedBg:setEnable(false);
	self.buffNameTxt.colorStr = Lua_ColorDefine.transColorStr(colorStr);
end

function Lua_DivineDomainTrialBuffHorItem:showSelected()
	if self.bSelectedItem then
		self.selectedSp:setEnable(true);
		self.selectedBg:setEnable(true);
	else
		self.buffBg:setGray(true);
		self.skillItem:setGray(true);
		self.selectedBg:setEnable(false);
		self.buffNameTxt.colorStr = Lua_ColorDefine.transColorStr("676767");
	end
end

function Lua_DivineDomainTrialBuffHorItem:showSelectingMode()
	self.selectedBg:setEnable(self.bSelectedItem);
end

function Lua_DivineDomainTrialBuffHorItem:onClickItemBg()
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		return;
	end
	self.clickTime = getTime();

	if not self.bBuffSelectMode then
		OperateAlert.showLangValue(764031);
		return;
	end

	if self.bSelectedItem then
		return;
	end

	DataCenter.divineDomainTrialData.curSelectingBuffId = self.data;
	Lua_MsgUtil.callFunc("UPDATE_DIVINEDOMAINTRIAL_SELECTING_BUFF");
end