-- 神域试炼关卡
Lua_DivineDomainTrialCommonItem = class("Lua_DivineDomainTrialCommonItem", Lua_ListCell);
function Lua_DivineDomainTrialCommonItem:ctor(p)
	self:superCall("ctor", p, "DivineDomainTrialCommonItem_skin");
end

function Lua_DivineDomainTrialCommonItem:buildShowItem()
	self:superCall("buildShowItem");

	self.passSp:setEnable(false);
	self.costObj:SetActive(false);
	self.freeTxt.text = nil;
	self.monsterIcon = Lua_ItemIcon.new(self.content);
	self.monsterIcon:setLocation(-192, 1);
	self.monsterIcon:setScale(0.86, 0.86);
	self.monsterIcon:setClick(self, self.onClickMonsterIcon);
	self.monsterIcon:setSiblingIndex(self.selectSp.siblingIndex);

	self.rewardList = Lua_DragList.new(self.content, 260, 87, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_DivineDomainTrialCommonRewardItem, 87, 87, 1);
	self.rewardList:setLocation(7, -1, 0);
	self.rewardList:setCellSpacing(0, 10);
	self:setSubList(self.rewardList);

	self.fightBtn:addClickFuntion(self, self.onClickFightBtn);
end

function Lua_DivineDomainTrialCommonItem:dispose()
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);
	if self.monsterIcon ~= nil then
		self.monsterIcon:dispose();
		self.monsterIcon = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end 
	self:superCall("dispose");
end

function Lua_DivineDomainTrialCommonItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local levelCfg = DataCenter.divineDomainTrialUtil:getDivineDomainTrialLevelConfig(self.data);
	if levelCfg == nil then
		return;
	end

	self.trialId = levelCfg.index;
	self.monsterId = levelCfg.monster;
	local cfg = DataCenter.divineDomainTrialUtil:getDivineDomainTrialConfig(self.trialId);
	if cfg == nil then
		return;
	end

	self.template_id = cfg.fight_id;
	local heroId = tonumber(cfg.hero_id);
	local heroVo = Lua_HeroVo.new(heroId);
	self.monsterIcon:setData(heroVo);


	local bSpecialTrial = DataCenter.divineDomainTrialUtil:checkSpecialTrial(self.trialId);
	list = levelCfg.pass_reward;
	self.rewardList:setArrayData(list);
	self.levelNameTxt.text = LanUtil.formateStr(764013, levelCfg.floor);

	if not self:checkSpecialDisplay(bSpecialTrial) then
		self:updateCostTxt();
		self:updateButton();
	end
end

function Lua_DivineDomainTrialCommonItem:checkSpecialDisplay(bSpecialTrial)
	if bSpecialTrial then
		local bPass = DataCenter.divineDomainTrialData:checkLevelState(self.data) == 1;
		local EnableWipeOut = DataCenter.divineDomainTrialUtil:checkSpecialWipeOut(self.data);
		if bPass and not EnableWipeOut then
			self.freeTxt.text = nil;
			self.costObj:SetActive(false);
			self.fightBtn:setEnable(false);
			self.passSp:setEnable(true);
			return true;
		end
	end
	self.passSp:setEnable(false);
end

function Lua_DivineDomainTrialCommonItem:updateCostTxt()
	local str;
	local residueCount = DataCenter.divineDomainTrialData:getCountDicByTrialId(self.trialId);
	residueCount = residueCount and residueCount or 0;
	if residueCount > 0 then
		str = LanUtil.getValue(764014);
		self.costObj:SetActive(false);
	else
		self.costObj:SetActive(true);
		local bSpecialTrial = DataCenter.divineDomainTrialUtil:checkSpecialTrial(self.trialId);
		local cost_item = DataCenter.divineDomainTrialUtil:getCostItem(bSpecialTrial, self.data);
		local tvo = Lua_ToolVo.createToolVo(cost_item[1], cost_item[2]);
		self.costIcon:setAltas(tvo.atlas, tvo.sprite);

		local colorStr;
		local hasCount = DataCenter.packData:getItemCountById(cost_item[1]);
		if hasCount < cost_item[2] then
			colorStr ="FF3315";
		else
			colorStr ="36F10F";
		end

		self.costCountTxt.text = cost_item[2];
		self.costCountTxt.colorStr = Lua_ColorDefine.transColorStr(colorStr);
	end
	self.freeTxt.text = str;
end

function Lua_DivineDomainTrialCommonItem:updateButton()
	local trialData = DataCenter.divineDomainTrialData:getDivineDomainTrialData(self.trialId);
	if trialData == nil then
		return;
	end

	local str;
	local btnStyle;
	local bGray = false;
	local levelState = DataCenter.divineDomainTrialData:checkLevelState(self.data);
	if levelState == 1 then
		str = LanUtil.getValue(764015);
		-- btnStyle = 16;
	elseif levelState == 2 then
		str = LanUtil.getValue(764016);
		-- btnStyle = 1
	elseif levelState == 3 then
		str = LanUtil.getValue(764016);
		-- btnStyle = 1
		bGray = true;
	end
	self.fightBtn.label = str;
	self.fightBtn:setGray(bGray);
	-- self.fightBtn:setStyle(btnStyle);
	self.fightBtn:setEnable(true);
end

function Lua_DivineDomainTrialCommonItem:onClickMonsterIcon()
	if not DataCenter.divineDomainTrialData:checkTrialOpened(self.trialId, true) then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(764012);
		return;
	end
	self.clickTime = getTime();

	if self.data == nil then
		return;
	end

	-- 申请monster通关记录
	Lua_ProxyManager.getProxy("Lua_DivineDomainTrialProxy"):sGetSLevelRecordInfo(self.data);
end

function Lua_DivineDomainTrialCommonItem:onClickFightBtn()
	if not DataCenter.divineDomainTrialData:checkTrialOpened(self.trialId, true) then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.5 then
		OperateAlert.showLangValue(764012);
		return;
	end
	self.clickTime = getTime();

	local levelState = DataCenter.divineDomainTrialData:checkLevelState(self.data);
	if levelState == 3 then
		local bSatisfy, grade = DataCenter.divineDomainTrialUtil:enableSatisfyLevel(self.data);
		if not bSatisfy then
			local str = LuaUtil.formateStr(764042, grade);
			OperateAlert.show(str);
		else
			OperateAlert.showLangValue(764043);
		end
		return;
	end

	if self:checkSelectingBuff() then
		return;
	end

	self:checkFighting();
end

function Lua_DivineDomainTrialCommonItem:checkSelectingBuff()
	if DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.DIVINEDOMAINTRIAL_BUFF) then
        return false;
    else
		local selectedBuffId = DataCenter.divineDomainTrialData:getBuffDicByTrialId(self.trialId);
		if selectedBuffId == nil or selectedBuffId == 0 then
			local tipsData = { des = 764045, posY = 30, neverTip = Lua_NeverTipDefine.DIVINEDOMAINTRIAL_BUFF,
	            btnType = 1, sureLabel = 764046, owner = self, cancelFun = self.checkFighting, sureFun = self.openBuffsWin
	        };
	        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	        return true;
		end
	end
end

function Lua_DivineDomainTrialCommonItem:checkResidueCount()
	local residueCount = DataCenter.divineDomainTrialData:getCountDicByTrialId(self.trialId);
	residueCount = residueCount and residueCount or 0;
	if residueCount <= 0 then
		local bSpecialTrial = DataCenter.divineDomainTrialUtil:checkSpecialTrial(self.trialId);
		local cost_item = DataCenter.divineDomainTrialUtil:getCostItem(bSpecialTrial, self.data);
		local tvo = Lua_ToolVo.createToolVo(cost_item[1], cost_item[2]);
		local hasCount = DataCenter.packData:getItemCountById(cost_item[1]);
		if hasCount < cost_item[2] then
			DataCenter.packUtil:openPathWindow(cost_item[1], false);
		else
			local tipsData = { 
				des = LanUtil.formateStr(764040, cost_item[2], spliceIconStrById(cost_item[1])), 
				btnType = 1, 
				owner = self, 
				sureFun = self.onSendFighting };
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		end
		return false;
	end
	return true;
end

function Lua_DivineDomainTrialCommonItem:checkFighting()
	if self:checkResidueCount() then 
		self:onSendFighting();
	end
end

-- 打开增益选择窗口
function Lua_DivineDomainTrialCommonItem:openBuffsWin()
	Lua_WindowUtil.openWin("Lua_DivineDomainTrialBuffWindow", Lua_WinParam.ACTION_OPEN, self.trialId);
end

function Lua_DivineDomainTrialCommonItem:onSendFighting()
	local levelState = DataCenter.divineDomainTrialData:checkLevelState(self.data);
	if levelState == 2 then
		local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(self.template_id);
		DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, self.template_id, sceneId, 0);
	elseif levelState == 1 then
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.template_id, self.data);
	end

end

function Lua_DivineDomainTrialCommonItem:onSceneShow(param)
	local data = { template_id = param, stage_id = self.data, monster_player_id = self.monsterId };
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, data);
end







-------------------------------------
Lua_DivineDomainTrialCommonRewardItem = class("Lua_DivineDomainTrialCommonRewardItem", Lua_ItemIconCell)
function Lua_DivineDomainTrialCommonRewardItem:buildShowItem()
	self:superCall("buildShowItem")

	self.itemIcon:setScale(0.7, 0.7, 1)
end

function Lua_DivineDomainTrialCommonRewardItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data[1], data[2]);
	self.itemIcon:setData(tvo);
end

function Lua_DivineDomainTrialCommonRewardItem:onPressClick()
    if self.data == nil then
        return;
    end

    local tvo = Lua_ToolVo.createToolVo(self.data[1], self.data[2]);
    DataCenter.packUtil:showItemInfo(tvo);
end